"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const util_1 = require("util");
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const test_commons_1 = require("../../../test-commons");
const rimraf = util_1.promisify(require('rimraf'));
const DEST_DIR = path_1.default.join(process.cwd(), 'src', 'test', 'generated', 'generators', 'react-typescript', 'entity-list');
const displayNameFunctionFile = path_1.default.join(DEST_DIR, 'display-name', 'getOwnerDTODisplayName.ts');
describe('codegen entity-list test', () => {
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        yield rimraf(`${DEST_DIR}/{*,.*}`);
        !fs_1.default.existsSync(DEST_DIR) && fs_1.default.mkdirSync(DEST_DIR, { recursive: true });
        // avoid exception on read i18n messages in mvp.ts, create file first TODO - fix in mpv.ts 'addScreenI18nKeyEn'
        fs_1.default.mkdirSync(path_1.default.join(DEST_DIR, 'core', 'i18n'), { recursive: true });
        fs_1.default.writeFileSync(path_1.default.join(DEST_DIR, 'core', 'i18n', 'en.json'), '{}');
    }));
    it('should generate standalone list screen - Owner', () => __awaiter(void 0, void 0, void 0, function* () {
        const standaloneListAnswers = {
            componentName: 'StandaloneOwnerList',
            route: 'standalone-owner-list',
            shouldAddToMenu: false,
            query: ownerListQuery,
            mutation: ownerDeleteMutation,
            type: 'list',
            mode: 'edit'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'StandaloneOwnerList.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(!fs_1.default.existsSync(componentPath));
        chai_1.expect(!fs_1.default.existsSync(displayNameFunctionFile));
        yield commons_1.generate(path_1.default.join(commons_1.GENERATORS_DIR, 'react-typescript', 'entity-list'), commons_1.opts(DEST_DIR, standaloneListAnswers, commons_1.SCHEMA_PATH));
        const expectListTag = `
        <Space direction="vertical" style={{ width: "100%" }}>
          <List
            itemLayout="horizontal"
            bordered
            dataSource={items}
            renderItem={item => <ListItem item={item} key={item?.id} />}
          />
        </Space>`;
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function StandaloneOwnerList() ');
        chai_1.expect(componentFile).to.contain('query Get_Owner_List {');
        chai_1.expect(componentFile).to.contain('mutation Delete_Owner($id: BigInteger!) {');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectListTag);
        // check that displayName function is NOT written for 'list'
        chai_1.expect(!fs_1.default.existsSync(displayNameFunctionFile));
    }));
    it('should generate standalone cards screen - Owner', () => __awaiter(void 0, void 0, void 0, function* () {
        const standaloneCardsAnswers = {
            componentName: 'StandaloneOwnerCards',
            route: 'standalone-owner-cards',
            shouldAddToMenu: false,
            query: ownerListQuery,
            mutation: ownerDeleteMutation,
            mode: 'edit'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'StandaloneOwnerCards.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(!fs_1.default.existsSync(componentPath));
        chai_1.expect(!fs_1.default.existsSync(displayNameFunctionFile));
        yield commons_1.generate(path_1.default.join(commons_1.GENERATORS_DIR, 'react-typescript', 'entity-list'), commons_1.opts(DEST_DIR, standaloneCardsAnswers, commons_1.SCHEMA_PATH));
        const expectCardsTag = `
        <Space direction="vertical" style={{ width: "100%" }}>
          {items.map(item => (
            <ItemCard item={item} key={item?.id} />
          ))}
        </Space>`;
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function StandaloneOwnerCards() ');
        chai_1.expect(componentFile).to.contain('query Get_Owner_List {');
        chai_1.expect(componentFile).to.contain('mutation Delete_Owner($id: BigInteger!) {');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectCardsTag);
        // check that displayName function is written for 'cards'
        chai_1.expect(fs_1.default.existsSync(displayNameFunctionFile));
    }));
});
const ownerListQuery = `
query Get_Owner_List {
  ownerList {
    id
    firstName
    lastName
    city
    address
    telephone
    email
  }
}
`;
const ownerDeleteMutation = `
mutation Delete_Owner($id: BigInteger!) {
  delete_Owner(id: $id)
}
`;
//# sourceMappingURL=entity-list.test.js.map